==> kubernetes-model-scheduling-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/scheduling/v1beta1/PriorityClassListFluent.java <==
package io.fabric8.kubernetes.api.model.scheduling.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PriorityClassListFluent<A extends PriorityClassListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,PriorityClass item);
  public A setToItems(Integer index,PriorityClass item);
  public A addToItems(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClass... items);
  public A addAllToItems(Collection<PriorityClass> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClass... items);
  public A removeAllFromItems(Collection<PriorityClass> items);
  public A removeMatchingFromItems(Predicate<PriorityClassBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PriorityClass> getItems();
  public List<PriorityClass> buildItems();
  public PriorityClass buildItem(Integer index);
  public PriorityClass buildFirstItem();
  public PriorityClass buildLastItem();
  public PriorityClass buildMatchingItem(Predicate<PriorityClassBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PriorityClassBuilder> predicate);
  public A withItems(List<PriorityClass> items);
  public A withItems(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClass... items);
  public Boolean hasItems();
  public PriorityClassListFluent.ItemsNested<A> addNewItem();
  public PriorityClassListFluent.ItemsNested<A> addNewItemLike(PriorityClass item);
  public PriorityClassListFluent.ItemsNested<A> setNewItemLike(Integer index,PriorityClass item);
  public PriorityClassListFluent.ItemsNested<A> editItem(Integer index);
  public PriorityClassListFluent.ItemsNested<A> editFirstItem();
  public PriorityClassListFluent.ItemsNested<A> editLastItem();
  public PriorityClassListFluent.ItemsNested<A> editMatchingItem(Predicate<PriorityClassBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,PriorityClassFluent<PriorityClassListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-scheduling-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/scheduling/v1beta1/PriorityClassListFluent.java <==
package io.fabric8.kubernetes.api.model.scheduling.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PriorityClassListFluent<A extends PriorityClassListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,PriorityClass item);
  public A setToItems(int index,PriorityClass item);
  public A addToItems(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClass... items);
  public A addAllToItems(Collection<PriorityClass> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClass... items);
  public A removeAllFromItems(Collection<PriorityClass> items);
  public A removeMatchingFromItems(Predicate<PriorityClassBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PriorityClass> getItems();
  public List<PriorityClass> buildItems();
  public PriorityClass buildItem(int index);
  public PriorityClass buildFirstItem();
  public PriorityClass buildLastItem();
  public PriorityClass buildMatchingItem(Predicate<PriorityClassBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PriorityClassBuilder> predicate);
  public A withItems(List<PriorityClass> items);
  public A withItems(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClass... items);
  public Boolean hasItems();
  public PriorityClassListFluent.ItemsNested<A> addNewItem();
  public PriorityClassListFluent.ItemsNested<A> addNewItemLike(PriorityClass item);
  public PriorityClassListFluent.ItemsNested<A> setNewItemLike(int index,PriorityClass item);
  public PriorityClassListFluent.ItemsNested<A> editItem(int index);
  public PriorityClassListFluent.ItemsNested<A> editFirstItem();
  public PriorityClassListFluent.ItemsNested<A> editLastItem();
  public PriorityClassListFluent.ItemsNested<A> editMatchingItem(Predicate<PriorityClassBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,PriorityClassFluent<PriorityClassListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
